searchData={"items":[{"type":"module","title":"GoogleAI","doc":"`GoogleAI` is an Elixir library that provides a community-maintained client for the Google AI API.","ref":"GoogleAI.html"},{"type":"function","title":"GoogleAI.client/1","doc":"Create a new GoogleAI client with the given `opts`.","ref":"GoogleAI.html#client/1"},{"type":"function","title":"Options - GoogleAI.client/1","doc":"* `:api_key` (`t:String.t/0`) - Required. The API key for the Google AI APIs.\n\n* `:api_version` - The version of the API to use. Certain features are only available in later version. The default value is `\"v1beta\"`.\n\n* `:base_url` (`t:String.t/0`) - The base URL for the Google AI APIs. The default value is `\"https://generativelanguage.googleapis.com\"`.","ref":"GoogleAI.html#client/1-options"},{"type":"function","title":"Examples - GoogleAI.client/1","doc":"iex> GoogleAI.client(api_key: \"asdfasdf\")\n  %GoogleAI.Client{\n    req: Req.new(\n      base_url: \"https://generativelanguage.googleapis.com\", \n      params: [key: \"asdfasdf\"], \n      path_params: [version: \"v1beta\"]\n    )\n  }\n\n  iex> GoogleAI.client(api_key: \"asdfasdf\", base_url: \"https://example.com\", api_version: \"v1\")\n  %GoogleAI.Client{\n    req: Req.new(\n      base_url: \"https://example.com\", \n      params: [key: \"asdfasdf\"], \n      path_params: [version: \"v1\"]\n    )\n  }","ref":"GoogleAI.html#client/1-examples"},{"type":"module","title":"GoogleAI.Client","doc":"The API client underlying calls to Google AI APIs.","ref":"GoogleAI.Client.html"},{"type":"type","title":"GoogleAI.Client.t/0","doc":"The type of the Google AI client.","ref":"GoogleAI.Client.html#t:t/0"},{"type":"module","title":"GoogleAI.Content","doc":"The module provides an implementation of the Google AI content generation APIs.\nThe API reference can be found at https://ai.google.dev/tutorials/rest_quickstart.","ref":"GoogleAI.Content.html"},{"type":"function","title":"GoogleAI.Content.count_tokens/2","doc":"Generates a model completion for a given prompt or conversation.\nCounts the number of tokens in the given `prompt` using the given model.","ref":"GoogleAI.Content.html#count_tokens/2"},{"type":"function","title":"Arguments - GoogleAI.Content.count_tokens/2","doc":"* `:model` - The `GoogleAI.Model` to use for this request.\n* `:prompt` - The text prompt to count the tokens in.","ref":"GoogleAI.Content.html#count_tokens/2-arguments"},{"type":"function","title":"Returns - GoogleAI.Content.count_tokens/2","doc":"A map containing the fields of the content tokens response.\n\nSee https://ai.google.dev/tutorials/rest_quickstart#count_tokens.","ref":"GoogleAI.Content.html#count_tokens/2-returns"},{"type":"function","title":"GoogleAI.Content.generate/3","doc":"Generates a model completion for a given prompt or conversation.","ref":"GoogleAI.Content.html#generate/3"},{"type":"function","title":"Arguments - GoogleAI.Content.generate/3","doc":"* `:model` - The `GoogleAI.Model` to use for this request.\n* `:prompt` - The text-only input or multi-turn conversation to send as a prompt\nto the AI model.\n* `:opts` - A keyword list of options that can be used to configure the request.","ref":"GoogleAI.Content.html#generate/3-arguments"},{"type":"function","title":"Returns - GoogleAI.Content.generate/3","doc":"A map containing the fields of the content generation response.\n\nSee https://ai.google.dev/tutorials/rest_quickstart#text-only_input.","ref":"GoogleAI.Content.html#generate/3-returns"},{"type":"type","title":"GoogleAI.Content.count_tokens_response/0","doc":"The structure of a GoogleAI count tokens response.\n\nHas the following format:\n\n```elixir\n%{\n  \"totalTokens\" => 8\n}\n```","ref":"GoogleAI.Content.html#t:count_tokens_response/0"},{"type":"type","title":"GoogleAI.Content.generation_config/0","doc":"Options that allow the configuration of the model output.","ref":"GoogleAI.Content.html#t:generation_config/0"},{"type":"type","title":"GoogleAI.Content.generation_request/0","doc":"The structure of a Google content generation request.","ref":"GoogleAI.Content.html#t:generation_request/0"},{"type":"type","title":"GoogleAI.Content.generation_response/0","doc":"The structure of a GoogleAI embedding response.\n\nHas the following format:\n\n```elixir\n%{\n  \"candidates\" => [\n    %{\n      \"content\" => %{\n        \"role\" => \"model\",\n        \"parts\" => [\n          %{\n            \"text\" => \"This is a test.\"\n          }\n        ]\n      },\n      \"finishReason\" => \"STOP\",\n      \"index\" => 0,\n    }\n  ]\n}\n```","ref":"GoogleAI.Content.html#t:generation_response/0"},{"type":"type","title":"GoogleAI.Content.role/0","doc":"The message role assigned to the content.","ref":"GoogleAI.Content.html#t:role/0"},{"type":"type","title":"GoogleAI.Content.safety_settings/0","doc":"A list of safety settings for the model.","ref":"GoogleAI.Content.html#t:safety_settings/0"},{"type":"module","title":"GoogleAI.Embedding","doc":"This module provides an implementation of the Google AI embeddings API.\nThe API reference can be found at https://ai.google.dev/tutorials/rest_quickstart#embedding.","ref":"GoogleAI.Embedding.html"},{"type":"function","title":"GoogleAI.Embedding.create/3","doc":"Create an embedding using the given `model` for the given `input`.","ref":"GoogleAI.Embedding.html#create/3"},{"type":"function","title":"Arguments - GoogleAI.Embedding.create/3","doc":"* `:model` - The `GoogleAI.Model` to use for this request.\n* `:input` - Either a single string or a list of strings. In the case that it is a list,\nthe `batchEmbedContents` action will be used.\n* `:opts` - options to include with the request.","ref":"GoogleAI.Embedding.html#create/3-arguments"},{"type":"function","title":"Options - GoogleAI.Embedding.create/3","doc":"* `:task_type` - The type of task to perform with the input.","ref":"GoogleAI.Embedding.html#create/3-options"},{"type":"function","title":"Returns - GoogleAI.Embedding.create/3","doc":"A map containing the fields of the embedding response.\n\nSee https://ai.google.dev/tutorials/rest_quickstart#embedding.","ref":"GoogleAI.Embedding.html#create/3-returns"},{"type":"type","title":"GoogleAI.Embedding.batch_embed_request/0","doc":"The structure of a GoogleAI batch embedding request.","ref":"GoogleAI.Embedding.html#t:batch_embed_request/0"},{"type":"type","title":"GoogleAI.Embedding.batch_embed_response/0","doc":"The structure of a GoogleAI batch embedding response.\n\nHas the following format:\n\n```elixir\n%{\n  \"embeddings\" => [%{\n    \"values\" => [\n      0.0234234,\n      0.3214135,\n      0.5645654,\n      ...\n    ]\n  }]\n}\n```","ref":"GoogleAI.Embedding.html#t:batch_embed_response/0"},{"type":"type","title":"GoogleAI.Embedding.embed_request/0","doc":"The structure of a GoogleAI embedding request.","ref":"GoogleAI.Embedding.html#t:embed_request/0"},{"type":"type","title":"GoogleAI.Embedding.embed_response/0","doc":"The structure of a GoogleAI embedding response.\n\nHas the following format:\n\n```elixir\n%{\n  \"embedding\" => %{\n    \"values\" => [\n      0.0234234,\n      0.3214135,\n      0.5645654,\n      ...\n    ]\n  }\n}\n```","ref":"GoogleAI.Embedding.html#t:embed_response/0"},{"type":"module","title":"GoogleAI.Http","doc":"HTTP utilities for GoogleAI APIs.","ref":"GoogleAI.Http.html"},{"type":"function","title":"GoogleAI.Http.get/1","doc":"Dispatch a GET request with the given `client`.","ref":"GoogleAI.Http.html#get/1"},{"type":"function","title":"Arguments - GoogleAI.Http.get/1","doc":"* `:client` - A `Req.Request` configured to dispatch as a GET request.","ref":"GoogleAI.Http.html#get/1-arguments"},{"type":"function","title":"Returns - GoogleAI.Http.get/1","doc":"A tuple indicating success or failure and containing the request body.","ref":"GoogleAI.Http.html#get/1-returns"},{"type":"function","title":"GoogleAI.Http.post/3","doc":"Dispatch a POST request for the given `model` and `action`.","ref":"GoogleAI.Http.html#post/3"},{"type":"function","title":"Arguments - GoogleAI.Http.post/3","doc":"* `:model` - A `GoogleAI.Model` to use for the request.\n* `:action` - The action to dispatch for the model.\n* `:json` - The JSON body to send with the request.","ref":"GoogleAI.Http.html#post/3-arguments"},{"type":"function","title":"Returns - GoogleAI.Http.post/3","doc":"A tuple indicating success or failure and containing the request body.","ref":"GoogleAI.Http.html#post/3-returns"},{"type":"type","title":"GoogleAI.Http.response/0","doc":"","ref":"GoogleAI.Http.html#t:response/0"},{"type":"type","title":"GoogleAI.Http.response/1","doc":"The structure of data returned from the post function.","ref":"GoogleAI.Http.html#t:response/1"},{"type":"module","title":"GoogleAI.Model","doc":"A struct representing a Google AI model.","ref":"GoogleAI.Model.html"},{"type":"function","title":"GoogleAI.Model.get/2","doc":"Get information about the model with the given `model_name`.","ref":"GoogleAI.Model.html#get/2"},{"type":"function","title":"Arguments - GoogleAI.Model.get/2","doc":"* `:client` - The `GoogleAI.Client` to use for this request.\n* `:model_name` - The name of the model to look up.","ref":"GoogleAI.Model.html#get/2-arguments"},{"type":"function","title":"Returns - GoogleAI.Model.get/2","doc":"A map containing the fields of the get model response.\n\nSee https://ai.google.dev/tutorials/rest_quickstart#get_model.","ref":"GoogleAI.Model.html#get/2-returns"},{"type":"function","title":"GoogleAI.Model.list/1","doc":"List information about the all models available on Google AI.","ref":"GoogleAI.Model.html#list/1"},{"type":"function","title":"Arguments - GoogleAI.Model.list/1","doc":"* `:client` - The `GoogleAI.Client` to use for this request.","ref":"GoogleAI.Model.html#list/1-arguments"},{"type":"function","title":"Returns - GoogleAI.Model.list/1","doc":"A map containing the fields of the list models response.\n\nSee https://ai.google.dev/tutorials/rest_quickstart#list_models","ref":"GoogleAI.Model.html#list/1-returns"},{"type":"function","title":"GoogleAI.Model.new/2","doc":"Create a new GoogleAI model from the given `client` and `opts`.\n\nThe function `new/1` will use the default GoogleAI API configuration.","ref":"GoogleAI.Model.html#new/2"},{"type":"function","title":"Options - GoogleAI.Model.new/2","doc":"* `:model` (`t:String.t/0`) - Required. The model name e.g. gemini-pro, gemini-pro-vision or embedding-001.\n\n* `:generation_config` (`t:keyword/0`) - The model generation configuration. These will be passed to requests as required.\n\n* `:safety_settings` (`t:keyword/0`) - The model safety settings. These will be passed to requests as required.","ref":"GoogleAI.Model.html#new/2-options"},{"type":"function","title":"Examples - GoogleAI.Model.new/2","doc":"iex> client = GoogleAI.client(api_key: \"asdfasdf\")\n  ...> GoogleAI.Model.new(client, model: \"gemini-pro\")\n  %GoogleAI.Model{\n    client: %GoogleAI.Client{\n      req: Req.new(\n        url: \"/:version/models/:model::action\",\n        base_url: \"https://generativelanguage.googleapis.com\",\n        params: [key: \"asdfasdf\"], \n        path_params: [version: \"v1beta\", model: \"gemini-pro\"]\n      )\n    },\n    model: \"gemini-pro\",\n    generation_config: nil,\n    safety_settings: nil\n  }","ref":"GoogleAI.Model.html#new/2-examples"},{"type":"type","title":"GoogleAI.Model.generation_config/0","doc":"Configuration used for tweaking model generation.","ref":"GoogleAI.Model.html#t:generation_config/0"},{"type":"type","title":"GoogleAI.Model.get_model_response/0","doc":"The structure of a GoogleAI get model response.\n\nHas the following format:\n\n```elixir\n%{\n  \"name\" => \"models/gemini-pro\",\n  \"version\" => \"001\",\n  \"displayName\" => \"Gemini Pro\",\n  \"description\" => \"The best model for scaling across a wide range of tasks\",\n  \"inputTokenLimit\" => 30720,\n  \"outputTokenLimit\" => 2048,\n  \"supportedGenerationMethods\" => [\n    \"generateContent\",\n    \"countTokens\"\n  ],\n  \"temperature\" => 0.9,\n  \"topP\" => 1,\n  \"topK\" => 1\n}\n```","ref":"GoogleAI.Model.html#t:get_model_response/0"},{"type":"type","title":"GoogleAI.Model.list_models_response/0","doc":"The structure of a GoogleAI list models response.\n\nHas the following format:\n\n```elixir\n%{\n  \"models\" => [\n    %{\n      \"name\" => \"models/gemini-pro\",\n      \"version\" => \"001\",\n      \"displayName\" => \"Gemini Pro\",\n      \"description\" => \"The best model for scaling across a wide range of tasks\",\n      \"inputTokenLimit\" => 30720,\n      \"outputTokenLimit\" => 2048,\n      \"supportedGenerationMethods\" => [\n        \"generateContent\",\n        \"countTokens\"\n      ],\n      \"temperature\" => 0.9,\n      \"topP\" => 1,\n      \"topK\" => 1\n    }\n  ]\n}\n```","ref":"GoogleAI.Model.html#t:list_models_response/0"},{"type":"type","title":"GoogleAI.Model.safety_settings/0","doc":"Configuration used for tweaking model safety.","ref":"GoogleAI.Model.html#t:safety_settings/0"},{"type":"type","title":"GoogleAI.Model.t/0","doc":"Type of the underlying model struct.","ref":"GoogleAI.Model.html#t:t/0"},{"type":"module","title":"GoogleAI.Utils","doc":"Miscellaneous utilities functions.","ref":"GoogleAI.Utils.html"},{"type":"function","title":"GoogleAI.Utils.camelize_keys/1","doc":"Camelize all keys in the given map or keyword-list.","ref":"GoogleAI.Utils.html#camelize_keys/1"},{"type":"function","title":"Arguments - GoogleAI.Utils.camelize_keys/1","doc":"* `:input` - A map or keyword-list to camelize.","ref":"GoogleAI.Utils.html#camelize_keys/1-arguments"},{"type":"function","title":"Returns - GoogleAI.Utils.camelize_keys/1","doc":"A string-keyed map with camelized keys.","ref":"GoogleAI.Utils.html#camelize_keys/1-returns"},{"type":"function","title":"Examples - GoogleAI.Utils.camelize_keys/1","doc":"iex> GoogleAI.Utils.camelize_keys(%{\"foo_bar\" => \"baz\"})\n  %{\"fooBar\" => \"baz\"}\n\n  iex> GoogleAI.Utils.camelize_keys(foo_bar: \"baz\")\n  %{\"fooBar\" => \"baz\"}","ref":"GoogleAI.Utils.html#camelize_keys/1-examples"},{"type":"function","title":"GoogleAI.Utils.merge_path_params/2","doc":"Merges any path params already set in the given `req` with the incoming list\nof `path_params`.","ref":"GoogleAI.Utils.html#merge_path_params/2"},{"type":"extras","title":"README","doc":"# README\n\n[![License](https://img.shields.io/hexpm/l/google_ai.svg)](https://github.com/jadengis/google_ai_ex/blob/master/LICENSE)\n[![Hex Package](https://img.shields.io/hexpm/v/google_ai.svg)](https://hex.pm/packages/google_ai)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-blue.svg)](https://hexdocs.pm/google_ai)\n[![CI](https://github.com/jadengis/google_ai_ex/actions/workflows/ci.yml/badge.svg)](https://github.com/jadengis/google_ai_ex/actions/workflows/ci.yml)\n\n`GoogleAI` is an Elixir library that provides a community-maintained Google AI API client.\n\nSee https://ai.google.dev/tutorials/rest_quickstart for more information of the Google AI REST API.","ref":"readme.html"},{"type":"extras","title":"Installation - README","doc":"The package can be installed by adding `google_ai` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:google_ai, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"},{"type":"extras","title":"Features - README","doc":"- [x] `generateContent` - Text-only input\n- [ ] `generateContent` - Text-and-image Input\n- [ ] `generateContent` - Multi-turn conversation\n- [x] `generateContent` - Configuration\n- [ ] `streamGenerateContent`\n- [x] `countTokens`\n- [x] `embedContent`\n- [x] `batchEmbedContents`\n- [x] Get model\n- [x] List models","ref":"readme.html#features"},{"type":"extras","title":"Configuration - README","doc":"You can configure `google_ai` in your mix config.exs (default $project_root/config/config.exs). If you're using Phoenix add the configuration in your config/dev.exs|test.exs|prod.exs files. An example config is:\n\n```elixir\nimport Config\n\nconfig :google_ai,\n  # find it at https://makersuite.google.com/app/apikey\n  api_key: \"your-api-key\",\n\n```","ref":"readme.html#configuration"},{"type":"extras","title":"License - README","doc":"MIT","ref":"readme.html#license"}],"content_type":"text/markdown"}